#ifndef _GEN_SNMP_H
#define _GEN_SNMP_H
/*
 * Copyright 07 Feb 1995 Sun Microsystems, Inc. All Rights Reserved
 * Copyright (c) 1993 Spider Systems Limited
 *
 * This Source Code is furnished under Licence, and may not be
 * copied or distributed without express written agreement.
 *
 * All rights reserved.  Made in Scotland.
 *
 * Authors: Alan Robertson, Peter Woodhouse, Duncan Walker, Jim Stewart
 *
 */

#ifndef SID_T
#define SID_T	uint32 /* type of subidentifiers */
#endif /* ~SID_T */

/*
 * Values for the 'ic_cmd' field of I_STR ioctls.
 * These indicate the request to be performed.
 * These should be ORed with the constants supplied below and in
 * the *_mib.h files, which specify the variables on which the
 * request should be performed.
 */

#define SNMPIOC			('M' << 8)

#define SNMP_GET_REQ		(SNMPIOC | (0 << 5))
#define SNMP_GETNEXT_REQ	(SNMPIOC | (1 << 5))
#define SNMP_SET_REQ		(SNMPIOC | (3 << 5))	/* old style set */
#define	SNMP_ITEST_REQ		(SNMPIOC | (4 << 5))
#define	SNMP_ISET_REQ		(SNMPIOC | (5 << 5))

#define SNMP_REQ_MASK		(SNMPIOC | (7 << 5))

/*
 * Values for the 'ic_cmd' field of I_STR ioctls.
 * These indicate the variables to be affected.
 * These should be ORed with the constants above, which specify
 * the type of request.
 */

#ifdef STCP
#define	SNMP_IF			0
#endif /* STCP */
#define	SNMP_IFENTRY		1
#ifdef STCP
#define	SNMP_ATENTRY		2
#define	SNMP_IP			3
#define	SNMP_IPADDRENTRY	4
#define	SNMP_IPROUTEENTRY	5
#define	SNMP_ICMP		6
#define	SNMP_TCP		7
#define	SNMP_TCPCONNENTRY	8
#define	SNMP_UDP		9
#define SNMP_UDPENTRY		10
#define SNMP_IPNETTOMEDIAENTRY	11
#endif /* STCP */
/*
 * The following value is a mask which can be used to extract the
 * variable type of an 'ic_cmd' type.
 */

#define SNMP_VAR_MASK		31

/*
 * Values for the 'ic_cmd' field of I_STR ioctls.
 * This indicates that an SNMP control message 
 * is being sent.
 */

#define SNMP_CONTROL		(SNMPIOC | (7 << 5) | 0)

/*
 * init structure for SNMP
 */

struct snmp_init
{
        uint8 prim_type;
        uint8 pad[3];
	unsigned long since;
};

#define SNMP_INIT		1

/*
 * interface registration/unregistration structure
 */

#define ID_MAXLEN		32

struct snmp_reg
{
        uint8 prim_type;		/* SNMP_REG or SNMP_UNREG */
        uint8 pad[3];
	unsigned long ident;		/* identifier of interface */
	unsigned long IfIndex;		/* interface number */
	SID_T ObjId[ID_MAXLEN];		/* lower driver's OID */
	unsigned long ObjId_len;	/* length of lower driver's OID */
};

#define SNMP_REG		2
#define SNMP_UNREG		3	/* future: for dynamic reconfig */

/*
 * SNMP_ITEST_REQ and SNMP_ISET_REQ requests contain the following
 * "var_info" structure (below) which gives the offset from the start
 * of the group structure of the variable to be "test"ed of "set".
 * The structure should be followed by the group structure, with
 * the "index" fields and the value to set/test filled in.
 */

struct var_info		/* used in SNMP_ITEST_REQ and SNMP_ISET_REQ */
{
	unsigned long version;		/* version number */
	unsigned long offset;		/* offset relative to full structure */
};

/*
 * The following macros calculates the offset of a field in a structure.
 *
 * The first is for arrays, and the second is for other field types.
 */
#define A_OFFSET(structure, field) ((unsigned long)(((struct structure *)0)->field))
/* Changed from OFFSET due to conflict */
#define S_OFFSET(structure, field) ((unsigned long)(&((struct structure *)0)->field))

/*
 * The following macro calculates the size of a field in a structure
 */
#define SIZE(structure, field) (sizeof(((struct structure *)0)->field))

#ifdef STCP
/*
 * trap structure for SNMP;
 * currently this is only used between drivers
 */

struct snmp_trap
{
	int prim_type;
	long generic_trap;
	long specific_trap;
	int info_len;			/* length of info in bytes */
	char info[1];			/* "interesting" information */
};

/*
 * values for "generic_trap"
 */

#define SNMP_TRAP_ENTSPEC	6

/*
 * values for "specific_trap" are the same as the interface status field
 * i.e. up(1), down(2), testing(3).
 */
#endif
#endif
