#ifndef _X25_MIB_H
#define _X25_MIB_H
/*
 * Copyright 18 Apr 1995 Sun Microsystems, Inc. All Rights Reserved
 * Copyright (c) 1993 Spider Systems Limited
 *
 * This Source Code is furnished under Licence, and may not be
 * copied or distributed without express written agreement.
 *
 * All rights reserved.  Made in Scotland.
 *
 * Authors: Alan Robertson, Peter Woodhouse, Duncan Walker, Jim Stewart
 *
 */

/*
 * Values for the 'ic_cmd' field of I_STR ioctls.
 * These indicate the variables to be affected.
 * These should be ored with the constants in "gen_snmp.h", which
 * indicate the action to be performed (e.g. get, getnext, test, set).
 */

#define SNMP_X25OPERENTRY		2
#define	SNMP_X25STATENTRY		3
#define SNMP_X25CHANNELENTRY		4
#define	SNMP_X25CIRCUITENTRY		5
#define	SNMP_X25			6
#define	SNMP_X25CLEAREDCIRCUITENTRY	7
#define SNMP_X25CALLPARMENTRY		8

#define CPARM_CREATE_REREF		9
#define CPARM_UNREF			10

/* values giving the maximum sizes of arrays */

#define CALLPARM_MAXLEN		32
#define X121ADDR_MAXLEN		17
#define PVSUP_MAXLEN		32
#define FACILITIES_MAXLEN	109

/*
 * the prefix for a reference into the call parm and
 * circuit tables. Add the index.
 */
#define CALLPARM_PREFIX	"1.3.6.1.2.1.10.5.9.1.1"
#define CIRCUIT_PREFIX  "1.3.6.1.2.1.10.5.5.1.1"

/*
 * Enumerated values
 */

#define IFMODE_DTE	1
#define IFMODE_DCE	2
#define IFMODE_DXE	3

#define PKTSEQ_MOD8	1
#define PKTSEQ_MOD128	2

/*
 * Note that the following structure is used to interface with data in
 * a file, and not a STREAMS driver.
 */
typedef struct mib_x25AdmnEntry {
	long	version;
	u_long	Index;			/* index of table */
	long	InterfaceMode;
	long	MaxActiveCircuits;
	long	PacketSequencing;
	u_long	RestartTimer;
	u_long	CallTimer;
	u_long	ResetTimer;
	u_long	ClearTimer;
	u_long	WindowTimer;
	u_long	DataRxmtTimer;
	u_long	InterruptTimer;
	u_long	RejectTimer;
	u_long	RegistrationRequestTimer;
	u_long	MinimumRecallTimer;
	long	RestartCount;
	long	ResetCount;
	long	ClearCount;
	long	DataRxmtCount;
	long	RejectCount;
	long	RegistrationRequestCount;
	long	NumberPVCs;
	SID_T	DefCallParamId[CALLPARM_MAXLEN];
	u_long	DefCallParamId_len;
	u_char	LocalAddress[X121ADDR_MAXLEN];
	u_long	LocalAddress_len;
	SID_T	ProtocolVersionSupported[PVSUP_MAXLEN];
	u_long	ProtocolVersionSupported_len;
} x25AdmnEntry_t;

typedef struct mib_x25OperEntry {
	long	version;
	u_long	Index;			/* index of table */
	long	InterfaceMode;
	long	MaxActiveCircuits;
	long	PacketSequencing;
	u_long	RestartTimer;
	u_long	CallTimer;
	u_long	ResetTimer;
	u_long	ClearTimer;
	u_long	WindowTimer;
	u_long	DataRxmtTimer;
	u_long	InterruptTimer;
	u_long	RejectTimer;
	u_long	RegistrationRequestTimer;
	u_long	MinimumRecallTimer;
	long	RestartCount;
	long	ResetCount;
	long	ClearCount;
	long	DataRxmtCount;
	long	RejectCount;
	long	RegistrationRequestCount;
	long	NumberPVCs;
	SID_T	DefCallParamId[CALLPARM_MAXLEN];
	u_long	DefCallParamId_len;
	u_char	LocalAddress[X121ADDR_MAXLEN];
	u_long	LocalAddress_len;
#define DLID_MAXLEN	32
	SID_T	DataLinkId[DLID_MAXLEN];
	u_long	DataLinkId_len;
	SID_T	ProtocolVersionSupported[PVSUP_MAXLEN];
	u_long	ProtocolVersionSupported_len;
} x25OperEntry_t;

typedef struct mib_x25StatEntry {
	long	version;
	u_long	Index;			/* index of table */
	u_long	InCalls;
	u_long	InCallRefusals;
	u_long	InProviderInitiatedClears;
	u_long	InRemotelyInitiatedResets;
	u_long	InProviderInitiatedResets;
	u_long	InRestarts;
	u_long	InDataPackets;
	u_long	InAccusedOfProtocolErrors;
	u_long	InInterrupts;
	u_long	OutCallAttempts;
	u_long	OutCallFailures;
	u_long	OutInterrupts;
	u_long	OutDataPackets;
	u_long	OutgoingCircuits;
	u_long	IncomingCircuits;
	u_long	TwowayCircuits;
	u_long	RestartTimeouts;
	u_long	CallTimeouts;
	u_long	ResetTimeouts;
	u_long	ClearTimeouts;
	u_long	DataRxmtTimeouts;
	u_long	InterruptTimeouts;
	u_long	RetryCountExceededs;
	u_long	ClearCountExceededs;
} x25StatEntry_t;

typedef struct mib_x25ChannelEntry {
	long	version;
	u_long	Index;			/* index of table */
	long	LIC;
	long	HIC;
	long	LTC;
	long	HTC;
	long	LOC;
	long	HOC;
} x25ChannelEntry_t;

typedef struct mib_x25CircuitEntry {
	long	version;
	u_long	Index;			/* index of table */
	long	Channel;
	long	Status;
#define	CIRC_STATUS_INVALID		1
#define	CIRC_STATUS_CLOSED		2
#define	CIRC_STATUS_CALLING		3
#define	CIRC_STATUS_OPEN		4
#define	CIRC_STATUS_CLEARING		5
#define	CIRC_STATUS_PVC			6
#define	CIRC_STATUS_PVCRESETTING	7
#define	CIRC_STATUS_STARTCLEAR		8
#define	CIRC_STATUS_STARTPVCRESET	9
#define	CIRC_STATUS_OTHER		10
	u_long	EstablishTime;
	long	Direction;
#define	DIRECTION_INCOMING	1
#define	DIRECTION_OUTGOING	2
#define	DIRECTION_PVC		3
#define	DIRECTION_DEF		DIRECTION_PVC
	u_long	InOctets;
	u_long	InPdus;
	u_long	InRemotelyInitiatedResets;
	u_long	InProviderInitiatedResets;
	u_long	InInterrupts;
	u_long	OutOctets;
	u_long	OutPdus;
	u_long	OutInterrupts;
	u_long	DataRetransmissionTimeouts;
	u_long	ResetTimeouts;
	u_long	InterruptTimeouts;
	SID_T	CallParamId[CALLPARM_MAXLEN];
	u_long	CallParamId_len;
#define	CALLPARM_DEF	"0.0"
	u_char	CalledDteAddress[X121ADDR_MAXLEN];
	u_long	CalledDteAddress_len;
#define	CALLEDDTE_DEF	""
	u_char	CallingDteAddress[X121ADDR_MAXLEN];
	u_long	CallingDteAddress_len;
#define	CALLINGDTE_DEF	""
	u_char	OriginallyCalledAddress[X121ADDR_MAXLEN];
	u_long	OriginallyCalledAddress_len;
#define	ORIGDTE_DEF	""
#define CIRC_DESC_MAXLEN	255
	u_char	Descr[CIRC_DESC_MAXLEN];
	u_long	Descr_len;
#define	CIRC_DESC_DEF	""
} x25CircuitEntry_t;

typedef struct mib_x25 {
	long	version;
	u_long	ClearedCircuitEntriesRequested;
	u_long	ClearedCircuitEntriesGranted;
} x25_t;

typedef struct mib_x25ClearedCircuitEntry {
	long	version;
	u_long	Index;			/* index of table */
	u_long	PleIndex;
	u_long	TimeEstablished;
	u_long	TimeCleared;
	long	Channel;
	long	ClearingCause;
	long	DiagnosticCode;
	u_long	InPdus;
	u_long	OutPdus;
	u_char	CalledAddress[X121ADDR_MAXLEN];
	u_long	CalledAddress_len;
	u_char	CallingAddress[X121ADDR_MAXLEN];
	u_long	CallingAddress_len;
	u_char	ClearFacilities[FACILITIES_MAXLEN];
	u_long	ClearFacilities_len;
} x25ClearedCircuitEntry_t;

#define CUG_MAXLEN	4
#define EXT_MAXLEN	40
#define FAC_MAXLEN	108

#define	THRUPUT_TCRESERVED1	1
#define	THRUPUT_TCRESERVED2	2
#define	THRUPUT_TC75		3
#define	THRUPUT_TC150		4
#define	THRUPUT_TC300		5
#define	THRUPUT_TC600		6
#define	THRUPUT_TC1200		7
#define	THRUPUT_TC2400		8
#define	THRUPUT_TC4800		9
#define	THRUPUT_TC9600		10
#define	THRUPUT_TC19200		11
#define	THRUPUT_TC48000		12
#define	THRUPUT_TC64000		13
#define	THRUPUT_TCRESERVED14	14
#define	THRUPUT_TCRESERVED15	15
#define	THRUPUT_TCRESERVED0	16
#define	THRUPUT_TCNONE		17
#define	THRUPUT_TCDEFAULT	18
#define	THRUPUT_DEF		THRUPUT_TCNONE

typedef struct mib_x25CallParmEntry {
	long	version;
	u_long	Index;			/* index of table */
	u_long	Status;
#define	CP_VALID		1
#define	CP_CREATE_REQUEST	2
#define	CP_UNDER_CREATION	3
#define	CP_INVALID		4
	u_long	RefCount;
	long	InPacketSize;
#define	INPKTSIZE_DEF		128
	long	OutPacketSize;
#define	OUTPKTSIZE_DEF		128
	long	InWindowSize;
#define	INWINSIZE_DEF		2
	long	OutWindowSize;
#define	OUTWINSIZE_DEF		2
	long	AcceptReverseCharging;
#define	ACCREV_DEFAULT		1
#define	ACCREV_ACCEPT		2
#define	ACCREV_REFUSE		3
#define	ACCREV_NEVERACCEPT	4
#define	ACCREV_DEF		ACCREV_REFUSE
	long	ProposeReverseCharging;
#define	PROPREV_DEFAULT		1
#define	PROPREV_REVERSE		2
#define	PROPREV_LOCAL		3
#define	PROPREV_DEF		PROPREV_LOCAL
	long	FastSelect;
#define	FS_DEFAULT		1
#define	FS_NOTSPECIFIED		2
#define	FS_FASTSELECT		3
#define	FS_RESTRICTEDFR		4
#define	FS_NOFASTSELECT		5
#define	FS_NORESTRICTEDFR	6
#define	FS_DEF			FS_NOFASTSELECT
	long	InThruPutClasSize;
	long	OutThruPutClasSize;
	u_char	Cug[CUG_MAXLEN];
	u_long	Cug_len;
#define	CUG_DEF			""
	u_char	Cugoa[CUG_MAXLEN];
	u_long	Cugoa_len;
#define	CUGOA_DEF		""
#define BCUG_MAXLEN		4
	u_char	Bcug[BCUG_MAXLEN];
	u_long	Bcug_len;
#define	BCUG_DEF		""
#define NUI_MAXLEN	108
	u_char	Nui[NUI_MAXLEN];
	u_long	Nui_len;
#define	NUI_DEF			""
	long	ChargingInfo;
#define	CHARGE_DEFAULT		1
#define	CHARGE_NOFACILITY	2
#define	CHARGE_NOCHARGINGINFO	3
#define	CHARGE_CHARGINGINFO	4
#define	CHARGE_DEF		CHARGE_NOFACILITY
#define RPOA_MAXLEN	108
	u_char	Rpoa[RPOA_MAXLEN];
	u_long	Rpoa_len;
#define	RPOA_DEF		""
	long	TrnstDly;
#define	TRNSTDLY_DEF		65536
	u_char	CallingExt[EXT_MAXLEN];
	u_long	CallingExt_len;
#define	CALLINGEXT_DEF		""
	u_char	CalledExt[EXT_MAXLEN];
	u_long	CalledExt_len;
#define	CALLEDEXT_DEF		""
	long	InMinThuPutCls;
#define	INMINTH_DEF		17
	long	OutMinThuPutCls;
#define	OUTMINTH_DEF		17
#define TDELAY_MAXLEN	6
	u_char	EndTrnsDly[TDELAY_MAXLEN];
	u_long	EndTrnsDly_len;
#define	TDELAY_DEF		""
#define PRIORITY_MAXLEN	6
	u_char	Priority[PRIORITY_MAXLEN];
	u_long	Priority_len;
#define	PRIORITY_DEF		""
#define PROT_MAXLEN	108
	u_char	Protection[PROT_MAXLEN];
	u_long	Protection_len;
#define	PROT_DEF		""
	long	ExptData;
#define	ED_DEFAULT		1
#define	ED_NOEXPTDATA		2
#define	ED_EXPTDATA		3
#define	ED_DEF			ED_NOEXPTDATA
#define UDATA_MAXLEN		128
	u_char	UserData[UDATA_MAXLEN];
	u_long	UserData_len;
#define	UDATA_DEF		""
	u_char	CallingNetworkFacilities[FAC_MAXLEN];
	u_long	CallingNetworkFacilities_len;
#define CALLINGFAC_DEF		""
	u_char	CalledNetworkFacilities[FAC_MAXLEN];
	u_long	CalledNetworkFacilities_len;
#define CALLEDFAC_DEF		""
} x25CallParmEntry_t;

struct cparm_create_reref
{
	struct mib_x25CallParmEntry entry;
	u_long oIndex;
};

struct xcparmrereff {
        unsigned char             xl_type;    /* Always XL_INFO */
        unsigned char             xl_command; /* Always M_CParmReRef */ 
        struct cparm_create_reref cparm_ref;
};

struct xcparmunreff {
        unsigned char    xl_type;             /* Always XL_INFO */
        unsigned char    xl_command;          /* Always M_CParmUnRef */ 
        unsigned long    index; 
};

struct xcircf {
        unsigned char    xl_type;       /* Always XL_INFO */
        unsigned char    xl_command;    /* Always M_CircuitId */
        unsigned long    index;	
        unsigned long    channel;
};

/* the prefix for protocol Version Identifiers */
#define	x25ProtocolVersion	"1.3.6.1.2.1.10.5.10"
#define x25protocolCcittV1976	1
#define x25protocolCcittV1980	2
#define x25protocolCcittV1984	3
#define x25protocolCcittV1988	4
#define x25protocolIso8208V1987	5
#define x25protocolIso8208V1989	6
#endif
